from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.base import BaseParser
from netCDF4 import Dataset


class GlobalNdvi300mV2Parser(BaseParser):
    """ Parser used to transform CLMS Ndvi 300m V2 products to GeoJSON."""

    def __init__(self):
        super().__init__(template='clms_global_ndvi_300m_v2_10daily.template')

    def convert(self, product_file_info):

        import os
        import time

        # Initialize values dict
        values = {}

        # filename without extension
        file_name = os.path.basename(product_file_info.get_product_path()).rpartition('.')[0]
        file_name_parts = file_name.split('_')

        # filename:: c_gls_NDVI300_202204110000_GLOBE_OLCI_V2.0.1.nc
        # date = file_name_parts[3]
        tile_id = file_name_parts[4]
        product_type = file_name_parts[2]
        title = file_name
        version = file_name_parts[6]
        # major_version = int(version[1])

        fn = product_file_info.get_product_path()
        ds = Dataset(fn)
        print(ds)

        parent_identifier = 'clms_global_ndvi_300m_v2_10daily_netcdf'

        values['id'] = parent_identifier + ':' + title
        values['title'] = ds.title
        values['parentidentifier'] = parent_identifier
        values['conformsto'] = 'https://www.opengis.net/def/crs/EPSG/0/4326'
        values['westbbox'] = -180
        values['southbbox'] = -60
        values['eastbbox'] = 180
        values['northbbox'] = 80
        values['tileid'] = tile_id
        values['resolution'] = 300
        values['producttype'] = product_type
        values['productVersion'] = version
        values['platformShortName'] = ds.platform
        values['beginposition'] = ds.time_coverage_start
        values['endposition'] = ds.time_coverage_end
        values['creationtime'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['catingestiondate'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['updatetime'] = time.strftime(
            '%Y-%m-%dT%H:%M:%SZ',
            product_file_info.storage.get_time_modified(product_file_info.get_product_path())
        )

        if self.jinja_template is None:
            self.with_template(self.template)

        specific_infos = self.splitted_treatment(product_file_info, values)

        # Generation of the output
        results = {}
        for specific in specific_infos:
            result = self.jinja_template.render(
                dict=specific.values,
                dirpath=specific.product_file_info.get_product_path().rpartition('/')[0],
                products=specific.product_file_info.datas,
                previews=specific.product_file_info.previews,
                metadatas=specific.product_file_info.metadatas,
                related=specific.product_file_info.related
            )
            results[specific.uid] = result

        return results

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):

        # for file_info_data in list(product_file_info.datas):
        #     if file_info_data.name.endswith('.nc'):
        #         file_info_data.title = 'NDVI'
        #         file_info_data.type = 'application/netcdf'
        #
        self.fix_products(product_file_info)
        return values['id']

    @staticmethod
    def fix_products(fileobject):
        for info in list(fileobject.related):
            if info.name.endswith('.nc'):
                info.title = 'NDVI'
                info.type = 'application/netcdf'
                fileobject.related.remove(info)
                fileobject.datas.append(info)
